@@ -362,5 +362,19 @@ ADD  `auto_ussd_step4_start_r` VARCHAR( 160 ) CHARACTER SET utf8 COLLATE utf8_ge
 
 /*1.22.1 changed bal_limit to float*/
 	@$db->updatequery("ALTER TABLE  `auto_ussd` CHANGE  `bal_limit`  `bal_limit` FLOAT NOT NULL");
+
+/*1.23 add fixed time and remain recharge*/
+	@$db->updatequery("ALTER TABLE  `auto_ussd` ADD `recharge_con_type` int(11) NOT NULL default '0',
+ADD  `fixed_time` varchar(10) NOT NULL,
+ADD  `remain_limit` int(11) NOT NULL default '0',
+ADD  `remain_set` int(11) NOT NULL default '0',
+ADD  `fixed_next_time` int(10) unsigned NOT NULL;");
+        if(!$rs || $rs[0] < 119){
+                @$db->updatequery("update `system` set `version`='119'");
+                @$db->updatequery("ALTER TABLE  `auto_ussd` ADD INDEX (  `sms_report_goip` )");
+                @$db->updatequery("ALTER TABLE  `auto_ussd` ADD INDEX (  `recharge_con_type` )");
+	}
+
+/*1.23 fixed bug of SMS Templates*/
 	echo "update done! <a href=''  target=_top>Return</a>";
 ?>
